# RL for JITAI optimization using simulated environments

This repository contains the official implementation for the paper: **Assessing the Impact of Context Inference Error and Partial Observability on RL Methods for Just-In-Time Adaptive Interventions**, Karine Karine, Predrag Klasnja, Susan A. Murphy, Benjamin M. Marlin, UAI 2023.

This paper was accepted at the Conference on Uncertainty in Artificial Intelligence, UAI 2023.

+ arXiv link: https://arxiv.org/abs/2305.09913

+ UAI 2023 link: https://proceedings.mlr.press/v216/karine23a.html

+ UAI 2023 poster: https://github.com/reml-lab/rl_jitai_simulation/tree/main/rl_jitai_simulation_poster.pdf

## Examples

See the [Examples](https://github.com/reml-lab/rl_jitai_simulation/tree/main/examples) directory for a list of examples that can be run locally or launched in Google Colab.

For example:

+ [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/reml-lab/rl_jitai_simulation/blob/main/examples/rl_jitai_simulation_quickstart.ipynb)  RL for JITAI Quickstart

+ [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/reml-lab/rl_jitai_simulation/blob/main/examples/rl_jitai_simulation_experiments.ipynb)  RL for JITAI Examples


## Citing this paper

```
@inproceedings{RLJITAI2023, 
title = {Assessing the Impact of Context Inference Error and Partial Observability on RL Methods for Just-In-Time Adaptive Interventions},
author = {Karine, Karine and Klasnja, Predrag and Murphy, Susan A. and Marlin, Benjamin M.},
booktitle = {Proceedings of the Thirty-Ninth Conference on Uncertainty in Artificial Intelligence},
pages = {1047--1057},
year = {2023},
volume = {216},
}
```

